[llvm-commits] [llvm] r57946 - in /llvm/trunk: include/llvm/Assembly/PrintModulePass.h lib/CodeGen/LLVMTargetMachine.cpp lib/VMCore/PrintModulePass.cpp tools/llvm-dis/llvm-dis.cpp tools/opt/opt.cpp

Daniel Dunbar daniel at zuster.org
Tue Oct 21 20:25:24 PDT 2008


Author: ddunbar
Date: Tue Oct 21 22:25:22 2008
New Revision: 57946

URL: http://llvm.org/viewvc/llvm-project?rev=57946&view=rev
Log:
Move Print*Pass to use raw_ostream.

Modified:
    llvm/trunk/include/llvm/Assembly/PrintModulePass.h
    llvm/trunk/lib/CodeGen/LLVMTargetMachine.cpp
    llvm/trunk/lib/VMCore/PrintModulePass.cpp
    llvm/trunk/tools/llvm-dis/llvm-dis.cpp
    llvm/trunk/tools/opt/opt.cpp

Modified: llvm/trunk/include/llvm/Assembly/PrintModulePass.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Assembly/PrintModulePass.h?rev=57946&r1=57945&r2=57946&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/LLVMTargetMachine.cpp (original)
+++ llvm/trunk/lib/CodeGen/LLVMTargetMachine.cpp Tue Oct 21 22:25:22 2008
@@ -151,7 +151,7 @@
   if (!Fast) {
     PM.add(createLoopStrengthReducePass(getTargetLowering()));
     if (PrintLSR)
-      PM.add(createPrintFunctionPass("\n\n*** Code after LSR ***\n", &cerr));
+      PM.add(createPrintFunctionPass("\n\n*** Code after LSR ***\n", &errs()));
   }
 
   PM.add(createGCLoweringPass());
@@ -168,7 +168,7 @@
   if (PrintISelInput)
     PM.add(createPrintFunctionPass("\n\n"
                                    "*** Final LLVM Code input to ISel ***\n",
-                                   &cerr));
+                                   &errs()));
 
   // Standard Lower-Level Passes.
 

Modified: llvm/trunk/lib/VMCore/PrintModulePass.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/VMCore/PrintModulePass.cpp?rev=57946&r1=57945&r2=57946&view=diff

==============================================================================
--- llvm/trunk/tools/llvm-dis/llvm-dis.cpp (original)
+++ llvm/trunk/tools/llvm-dis/llvm-dis.cpp Tue Oct 21 22:25:22 2008
@@ -24,6 +24,7 @@
 #include "llvm/Support/ManagedStatic.h"
 #include "llvm/Support/MemoryBuffer.h"
 #include "llvm/Support/Streams.h"
+#include "llvm/Support/raw_ostream.h"
 #include "llvm/System/Signals.h"
 #include <iostream>
 #include <fstream>
@@ -117,7 +118,7 @@
     // All that llvm-dis does is write the assembly to a file.
     if (!DontPrint) {
       PassManager Passes;
-      OStream L(*Out);
+      raw_os_ostream L(*Out);
       Passes.add(createPrintModulePass(&L));
       Passes.run(*M.get());
     }

Modified: llvm/trunk/tools/opt/opt.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/tools/opt/opt.cpp?rev=57946&r1=57945&r2=57946&view=diff

==============================================================================
--- llvm/trunk/tools/opt/opt.cpp (original)
+++ llvm/trunk/tools/opt/opt.cpp Tue Oct 21 22:25:22 2008
@@ -30,6 +30,7 @@
 #include "llvm/Support/PluginLoader.h"
 #include "llvm/Support/Streams.h"
 #include "llvm/Support/SystemUtils.h"
+#include "llvm/Support/raw_ostream.h"
 #include "llvm/LinkAllPasses.h"
 #include "llvm/LinkAllVMCore.h"
 #include <iostream>
@@ -543,7 +544,7 @@
       }
       
       if (PrintEachXForm)
-        Passes.add(createPrintModulePass(&cerr));
+        Passes.add(createPrintModulePass(&errs()));
     }
     
     // If -std-compile-opts was specified at the end of the pass list, add them.





More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/Assembly/PrintModulePass.h (original)
+++ llvm/trunk/include/llvm/Assembly/PrintModulePass.h Tue Oct 21 22:25:22 2008
@@ -18,21 +18,21 @@
 #ifndef LLVM_ASSEMBLY_PRINTMODULEPASS_H
 #define LLVM_ASSEMBLY_PRINTMODULEPASS_H
 
-#include "llvm/Support/Streams.h"
 #include <string>
 
 namespace llvm {
   class FunctionPass;
   class ModulePass;
+  class raw_ostream;
   
   /// createPrintModulePass - Create and return a pass that writes the
-  /// module to the specified OStream.
-  ModulePass *createPrintModulePass(llvm::OStream *OS, bool DeleteStream=false);
+  /// module to the specified raw_ostream.
+  ModulePass *createPrintModulePass(raw_ostream *OS, bool DeleteStream=false);
   
   /// createPrintFunctionPass - Create and return a pass that prints
   /// functions to the specified OStream as they are processed.
   FunctionPass *createPrintFunctionPass(const std::string &Banner,
-                                        llvm::OStream *OS, 
+                                        raw_ostream *OS, 
                                         bool DeleteStream=false);  
 
 } // End llvm namespace
@@ -18,21 +18,21 @@
   
   /// createPrintFunctionPass - Create and return a pass that prints
-  /// functions to the specified OStream as they are processed.
+  /// functions to the specified raw_ostream as they are processed.
   FunctionPass *createPrintFunctionPass(const std::string &Banner,

Modified: llvm/trunk/lib/CodeGen/LLVMTargetMachine.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/LLVMTargetMachine.cpp?rev=57946&r1=57945&r2=57946&view=diff

==============================================================================
--- llvm/trunk/lib/VMCore/PrintModulePass.cpp (original)
+++ llvm/trunk/lib/VMCore/PrintModulePass.cpp Tue Oct 21 22:25:22 2008
@@ -17,18 +17,19 @@
 #include "llvm/Module.h"
 #include "llvm/Pass.h"
 #include "llvm/Support/Compiler.h"
+#include "llvm/Support/raw_ostream.h"
 using namespace llvm;
 
 namespace {
 
   class VISIBILITY_HIDDEN PrintModulePass : public ModulePass {
-    OStream *Out;           // ostream to print on
+    raw_ostream *Out;       // raw_ostream to print on
     bool DeleteStream;      // Delete the ostream in our dtor?
   public:
     static char ID;
-    PrintModulePass() : ModulePass(intptr_t(&ID)), Out(&cerr), 
+    PrintModulePass() : ModulePass(intptr_t(&ID)), Out(&errs()), 
       DeleteStream(false) {}
-    PrintModulePass(OStream *o, bool DS)
+    PrintModulePass(raw_ostream *o, bool DS)
       : ModulePass(intptr_t(&ID)), Out(o), DeleteStream(DS) {}
     
     ~PrintModulePass() {
@@ -36,7 +37,8 @@
     }
     
     bool runOnModule(Module &M) {
-      (*Out) << M << std::flush;
+      (*Out) << M;
+      Out->flush();
       return false;
     }
     
@@ -47,13 +49,13 @@
   
   class PrintFunctionPass : public FunctionPass {
     std::string Banner;     // String to print before each function
-    OStream *Out;           // ostream to print on
+    raw_ostream *Out;       // raw_ostream to print on
     bool DeleteStream;      // Delete the ostream in our dtor?
   public:
     static char ID;
-    PrintFunctionPass() : FunctionPass(intptr_t(&ID)), Banner(""), Out(&cerr), 
+    PrintFunctionPass() : FunctionPass(intptr_t(&ID)), Banner(""), Out(&errs()), 
                           DeleteStream(false) {}
-    PrintFunctionPass(const std::string &B, OStream *o, bool DS)
+    PrintFunctionPass(const std::string &B, raw_ostream *o, bool DS)
       : FunctionPass(intptr_t(&ID)), Banner(B), Out(o), DeleteStream(DS) {}
     
     inline ~PrintFunctionPass() {
@@ -65,6 +67,7 @@
     //
     bool runOnFunction(Function &F) {
       (*Out) << Banner << static_cast<Value&>(F);
+      Out->flush();
       return false;
     }
     
@@ -82,15 +85,17 @@
 Y("print-function","Print function to stderr");
 
 /// createPrintModulePass - Create and return a pass that writes the
-/// module to the specified OStream.
-ModulePass *llvm::createPrintModulePass(llvm::OStream *OS, bool DeleteStream) {
+/// module to the specified raw_ostream.
+ModulePass *llvm::createPrintModulePass(llvm::raw_ostream *OS, 
+                                        bool DeleteStream) {
   return new PrintModulePass(OS, DeleteStream);
 }
 
 /// createPrintFunctionPass - Create and return a pass that prints
 /// functions to the specified OStream as they are processed.
 FunctionPass *llvm::createPrintFunctionPass(const std::string &Banner,
-                                      OStream *OS, bool DeleteStream) {
+                                            llvm::raw_ostream *OS, 
+                                            bool DeleteStream) {
   return new PrintFunctionPass(Banner, OS, DeleteStream);
 }
 
@@ -82,15 +85,17 @@
 
 /// createPrintFunctionPass - Create and return a pass that prints
-/// functions to the specified OStream as they are processed.
+/// functions to the specified raw_ostream as they are processed.
 FunctionPass *llvm::createPrintFunctionPass(const std::string &Banner,

Modified: llvm/trunk/tools/llvm-dis/llvm-dis.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/tools/llvm-dis/llvm-dis.cpp?rev=57946&r1=57945&r2=57946&view=diff

==============================================================================